
# Meta encoding

Gives ASP semantics for the reification predicates as done in [How to build your own ASP system?!](https://arxiv.org/abs/2008.06692)

::: src/metasp/encodings/meta.lp
    handler: asp
    options:
        glossary:
            include_references: false
            include_undocumented: false
        predicate_table:
            include_undocumented: false
        encodings:
            git_link: true
        start_level: 1
